@@ -7,9 +7,9 @@ from kamaqi.show import show
 from kamaqi.remove import remove
 from kamaqi.upgrade import upgrade
 
-app = typer.Typer(help="A command line app for creating APIs with FastAPI")
+app = typer.Typer(help="A command line app for creating Backends with FastAPI")
 
-__version__ = "0.1.7"
+__version__ = "0.1.8"
 
 
 def version_callback(value: bool):
